# Fluent API Workflow

A clean example of the new fluent `HubBuilder` API.

This is the recommended way to use TrackNado programmatically. It provides a readable, chained interface for constructing hubs.

[View full source code on GitHub](https://github.com/alsmith151/TrackNado/blob/main/examples/refactored_make_hub.py)
